@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: SOAP::Test.pm,v 0.46 2001/01/31 16:30:24 $
+# $Id: SOAP::Test.pm,v 0.51 2001/07/18 15:15:14 $
 #
 # ======================================================================
 
@@ -12,7 +12,7 @@ package SOAP::Test;
 
 use 5.004;
 use vars qw($VERSION $TIMEOUT);
-$VERSION = '0.46';
+$VERSION = '0.51';
 
 $TIMEOUT = 5;
 
@@ -42,7 +42,7 @@ package SOAP::Test::Server;
 
 use strict;
 use Test;
-use SOAP::Lite on_fault => sub{ref $_[1] ? $_[1] : new SOAP::SOM};
+use SOAP::Lite;
 
 sub run_for {
   my $proxy = shift or die "Proxy/endpoint is not specified";
@@ -58,7 +58,9 @@ sub run_for {
   }
   # ------------------------------------------------------
 
-  plan tests => 32;
+  plan tests => 49;
+
+  eval q!use SOAP::Lite on_fault => sub{ref $_[1] ? $_[1] : new SOAP::SOM}; 1! or die;
 
   print "Perl SOAP server test(s)...\n";
 
@@ -76,6 +78,13 @@ sub run_for {
   $r = $s->getStateStruct({item1 => 1, item2 => 4})->result;
   ok(ref $r && $r->{item2} eq 'Arkansas'); 
 
+  {
+    my $autoresult = $s->autoresult;
+    $s->autoresult(1);
+    ok($s->getStateName(1) eq 'Alabama');
+    $s->autoresult($autoresult);
+  }
+
   print "Autobinding of output parameters test(s)...\n";
 
   $s->uri('urn:/My/Parameters');
@@ -85,11 +94,46 @@ sub run_for {
   ok($result == $param1 && $param2->value == 24); 
 
   print "Header manipulation test(s)...\n";
-
   $a = $s->addheader(2, SOAP::Header->name(my => 123)); 
   ok(ref $a->header && $a->header->{my} eq '123123'); 
   ok($a->headers eq '123123'); 
 
+  print "Echo untyped data test(s)...\n";
+  $a = $s->echotwo(11, 12);
+  ok($a->result == 11); 
+
+  print "mustUnderstand test(s)...\n";
+  $s->echo(SOAP::Header->name(somethingelse => 123)
+                       ->mustUnderstand(1));
+  ok($s->call->faultstring =~ /Header has mustUnderstand attribute/);
+
+  $s->echo(SOAP::Header->name(somethingelse => 123)
+                       ->mustUnderstand(1)
+                       ->actor('http://notme/'));
+  ok(!defined $s->call->fault);
+
+  print "dispatch_from test(s)...\n";
+  eval "use SOAP::Lite
+    uri => 'http://my.own.site.com/My/Examples',
+    dispatch_from => ['A', 'B'],
+    proxy => '$proxy',
+  ; 1" or die;
+
+  eval { C->c };
+  ok($@ =~ /Can't locate object method "c"/);
+
+  eval { A->a };
+  ok(!$@ && SOAP::Lite->self->call->faultstring =~ /Failed to access class \(A\)/);
+
+  eval "use SOAP::Lite
+    dispatch_from => 'A',
+    uri => 'http://my.own.site.com/My/Examples',
+    proxy => '$proxy',
+  ; 1" or die;
+
+  eval { A->a };
+  ok(!$@ && SOAP::Lite->self->call->faultstring =~ /Failed to access class \(A\)/);
+
   print "Object autobinding and SOAP:: prefix test(s)...\n";
 
   eval "use SOAP::Lite +autodispatch =>
@@ -122,12 +166,12 @@ sub run_for {
   print "VersionMismatch test(s)...\n";
 
   {
+    local $SOAP::Constants::NS_ENV = 'http://schemas.xmlsoap.org/new/envelope/';
     my $s = SOAP::Lite
       -> uri('http://my.own.site.com/My/Examples')                
       -> proxy($proxy)
       -> on_fault(sub{})
     ;
-    $s->serializer->attr({%{$s->serializer->attr}, 'xmlns:~V' => 'http://schemas.xmlsoap.org/new/envelope/'});
     $r = $s->dosomething;
     ok(ref $r && $r->faultcode =~ /:VersionMismatch/);
   }
@@ -188,19 +232,30 @@ sub run_for {
     ;
     ok($s->getStateName(1)->result eq 'Alabama'); 
 
-    $s-> on_action(sub{'"wrong_SOAPAction_here"'});
-    ok($s->getStateName(1)->faultdetail =~ /SOAPAction shall match/); 
+    $s->on_action(sub{'"wrong_SOAPAction_here"'});
+    ok($s->getStateName(1)->faultstring =~ /SOAPAction shall match/); 
   }
 
   {
+    my $on_fault_was_called = 0;
     print "Die in server method test(s)...\n";
     my $s = SOAP::Lite
       -> uri('http://my.own.site.com/My/Parameters')                
       -> proxy($proxy)
+      -> on_fault(sub{$on_fault_was_called++;return})
     ;
-    ok($s->die_simply()->faultdetail =~ /Something bad/);
+    ok($s->die_simply()->faultstring =~ /Something bad/);
+    ok($on_fault_was_called > 0);
     my $detail = $s->die_with_object()->dataof(SOAP::SOM::faultdetail . '/[1]');
+    ok($on_fault_was_called > 1);
     ok(ref $detail && $detail->name =~ /(^|:)something$/);
+
+    # get Fault as hash of subelements
+    my $fault = $s->die_with_fault()->fault;
+    ok($fault->{faultcode} =~ ':Server.Custom');
+    ok($fault->{faultstring} eq 'Died in server method');
+    ok(ref $fault->{detail}->{BadError} eq 'BadError');
+    ok($fault->{faultactor} eq 'http://www.soaplite.com/custom');
   }
 
   print "Method with attributes test(s)...\n";
@@ -218,9 +273,19 @@ sub run_for {
     -> proxy($proxy)
   ;
 
-  ok($s->getStateName(1)->faultdetail =~ /Denied access to method \(getStateName\) in class \(main\)/);
+  ok($s->getStateName(1)->faultstring =~ /Denied access to method \(getStateName\) in class \(main\)/);
 
-  ok($s->call('a:getStateName' => 1)->faultdetail =~ /Denied access to method \(getStateName\) in class \(main\)/);
+  ok($s->call('a:getStateName' => 1)->faultstring =~ /Denied access to method \(getStateName\) in class \(main\)/);
+
+  print "Number of parameters test(s)...\n";
+
+  $s = SOAP::Lite
+    -> uri('http://my.own.site.com/My/Parameters')                
+    -> proxy($proxy)
+  ;
+  { my @all = $s->echo->paramsall; ok(@all == 0) }
+  { my @all = $s->echo(1)->paramsall; ok(@all == 1) }
+  { my @all = $s->echo((1) x 10)->paramsall; ok(@all == 10) }
 
   print "Memory refresh test(s)...\n";
 
@@ -234,7 +299,7 @@ sub run_for {
     -> proxy($proxy)
   ;
 
-  ok($s->getStateName(1)->faultdetail =~ /Denied access to method \(getStateName\) in class \(main\)/);
+  ok($s->getStateName(1)->faultstring =~ /Denied access to method \(getStateName\) in class \(main\)/);
 
   print "Different settings for method and namespace test(s)...\n";
 
@@ -258,7 +323,8 @@ sub run_for {
 
   ok($@ =~ /Can't find namespace for method \(a:getStateName\)/);
 
-  $s->serializer->attr->{xmlns} = 'urn:/My/Examples';
+  $s->serializer->namespaces->{'urn:/My/Examples'} = '';
+
   ok($s->getStateName(1)->result eq 'Alabama');
 
   eval "use SOAP::Lite 
@@ -268,6 +334,16 @@ sub run_for {
   $s = new SOAP::Lite;
 
   ok($s->getStateName(1)->result eq 'Alabama');
+
+  SOAP::Trace->import(transport => 
+    sub {$_[0]->content_type('something/wrong') if UNIVERSAL::isa($_[0] => 'HTTP::Request')}
+  );
+
+  if ($proxy =~ /^tcp:/) {
+    skip('No Content-Type checks for tcp: protocol on server side' => undef);
+  } else {
+    ok($s->getStateName(1)->faultstring =~ /Content-Type must be/);
+  }
 }
 
 # ======================================================================
