@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: Test.pm 341 2009-09-30 18:34:58Z kutterma $
+# $Id: XMLRPC::Test.pm,v 0.51 2001/07/18 15:15:14 $
 #
 # ======================================================================
 
@@ -12,7 +12,7 @@ package XMLRPC::Test;
 
 use 5.004;
 use vars qw($VERSION $TIMEOUT);
-use version; $VERSION = qv('0.710.10');
+$VERSION = '0.51';
 
 $TIMEOUT = 5;
 
@@ -20,7 +20,7 @@ $TIMEOUT = 5;
 
 package My::PingPong; # we'll use this package in our tests
 
-sub new {
+sub new { 
   my $self = shift;
   my $class = ref($self) || $self;
   bless {_num=>shift} => $class;
@@ -58,7 +58,7 @@ sub run_for {
   }
   # ------------------------------------------------------
 
-  plan tests => 17;
+  plan tests => 16;
 
   eval q!use XMLRPC::Lite on_fault => sub{ref $_[1] ? $_[1] : new XMLRPC::SOM}; 1! or die;
 
@@ -68,14 +68,14 @@ sub run_for {
     -> proxy($proxy)
   ;
 
-  ok($s->call('My.Examples.getStateName', 1)->result eq 'Alabama');
-  ok($s->call('My.Examples.getStateNames', 1,4,6,13)->result =~ /^Alabama\s+Arkansas\s+Colorado\s+Illinois\s*$/);
+  ok($s->call('My.Examples.getStateName', 1)->result eq 'Alabama'); 
+  ok($s->call('My.Examples.getStateNames', 1,4,6,13)->result =~ /^Alabama\s+Arkansas\s+Colorado\s+Illinois\s*$/); 
 
   $r = $s->call('My.Examples.getStateList', [1,2,3,4])->result;
-  ok(ref $r && $r->[0] eq 'Alabama');
+  ok(ref $r && $r->[0] eq 'Alabama'); 
 
   $r = $s->call('My.Examples.getStateStruct', {item1 => 1, item2 => 4})->result;
-  ok(ref $r && $r->{item2} eq 'Arkansas');
+  ok(ref $r && $r->{item2} eq 'Arkansas'); 
 
   print "dispatch_from test(s)...\n";
   eval "use XMLRPC::Lite
@@ -94,7 +94,7 @@ sub run_for {
   ok(XMLRPC::Lite->autodispatched);
 
   # forget everything
-  XMLRPC::Lite->self(undef);
+  XMLRPC::Lite->self(undef); 
 
   {
     my $on_fault_was_called = 0;
@@ -123,12 +123,12 @@ sub run_for {
 
   print "Memory refresh test(s)...\n";
 
-  # Funny test.
+  # Funny test. 
   # Let's forget about ALL settings we did before with 'use XMLRPC::Lite...'
-  XMLRPC::Lite->self(undef);
+  XMLRPC::Lite->self(undef); 
   ok(!defined XMLRPC::Lite->self);
 
-  eval "use XMLRPC::Lite
+  eval "use XMLRPC::Lite 
     proxy => '$proxy'; 1" or die;
 
   print "Global settings test(s)...\n";
@@ -136,7 +136,7 @@ sub run_for {
 
   ok($s->call('My.Examples.getStateName', 1)->result eq 'Alabama');
 
-  SOAP::Trace->import(transport =>
+  SOAP::Trace->import(transport => 
     sub {$_[0]->content_type('something/wrong') if UNIVERSAL::isa($_[0] => 'HTTP::Request')}
   );
 
@@ -144,13 +144,7 @@ sub run_for {
     skip('No Content-Type checks for tcp: protocol on server side' => undef);
   } else {
     ok($s->call('My.Examples.getStateName', 1)->faultstring =~ /Content-Type must be/);
-  }
-
-  # check status for fault messages
-  if ($proxy =~ /^http/) {
-    ok($s->transport->status =~ /^200/);
-  } else {
-    skip('No Status checks for non http protocols on server side' => undef);
+    1;
   }
 }
 
