@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: TCP.pm 341 2009-09-30 18:34:58Z kutterma $
+# $Id: XMLRPC::Transport::TCP.pm,v 0.51 2001/07/18 15:15:14 $
 #
 # ======================================================================
 
@@ -12,10 +12,9 @@ package XMLRPC::Transport::TCP;
 
 use strict;
 use vars qw($VERSION);
+$VERSION = '0.51';
 
-use XMLRPC::Lite; $VERSION = $XMLPRC::Lite::VERSION;
-
-
+use XMLRPC::Lite;
 use SOAP::Transport::TCP;
 
 # ======================================================================
